@@ -27,8 +27,13 @@ $(function() {
   // set options for jQuery.socialbutton
   var callbacks = {
     twitter: function(url, title) {
+      var link = url;
+      var pos = 0;
+      if ((pos = url.indexOf('#')) > 0) {
+        link = url.substr(0, pos)
+      }
       return {
-        url: url,
+        url: link,
         text: title,
         button: 'horizontal',
         lang: $('html').attr('lang').substr(0,2)
@@ -39,7 +44,7 @@ $(function() {
       return {
         url: url,
         title: title,
-        button: 'standard'
+        button: 'simple-balloon'
       };
     },
 
@@ -82,7 +87,7 @@ $(function() {
     $('.socialbuttons').css('height', '1em')
     var bottom = $(window).height() + $(window).scrollTop();
 
-    $($tDiary.blogkit ? '.day' : '.section')
+    $($tDiary.blogkit ? '.day' : '.day .section')
       .filter(function() {
         return bottom > $(this).offset().top;
       })
@@ -90,13 +95,19 @@ $(function() {
         return $(this).find('.socialbutton').size() == 0
       })
       .each(function() {
+        var anchor = $(this).find('h3 a');
         if ($tDiary.blogkit) {
           var link = $(this).children('h2').find('a:first').get(0);
           var url = link ? link.href : document.URL;
           var title = $(this).children('h2').find('.title').text();
+        } else if (anchor.size() == 0) {
+          // The section may not have an anchor on etdiary style.
+          // https://github.com/tdiary/tdiary-contrib/issues/59
+          var url = ($(this).parents('.day').find('h2 a:first').get(0)||'').href;
+          var title = $(this).parents('.day').find('h2 .title').text();
         } else {
-          var url = $(this).children('h3').children('a').get(0).href;
-          var title = $(this).children('h3').children('a').attr('title');
+          var url = anchor.get(0).href;
+          var title = anchor.attr('title');
         }
         if (url && title) {
           // console.debug('loading socialbutton: ' + title);
